@@ -52,13 +52,16 @@ module Rabbit
         succeeded = false
         application.signal_connect("command-line") do |_, command_line|
           application.activate
-          0
+          succeeded ? 0 : 1
         end
         application.signal_connect("activate") do
-          succeeded = __send__("do_#{@options.action}")
+          begin
+            succeeded = __send__("do_#{@options.action}")
+          rescue
+            @logger.error($!)
+          end
         end
-        application.run
-        succeeded
+        application.run.zero?
       end
 
       private
@@ -444,7 +447,7 @@ module Rabbit
                     Array,
                     _("Set page margin.")) do |margins|
             begin
-              top, right, bottom, left = Utils.parse_four_dimensions(margins)
+              top, right, bottom, left = Utils.parse_four_way(margins)
               options.page_margin_top = top
               options.page_margin_right = right
               options.page_margin_bottom = bottom
@@ -648,6 +651,7 @@ module Rabbit
         add_source_dialog_filter(dialog, "RD files", "*.rd")
         add_source_dialog_filter(dialog, "Hiki files", "*.hiki")
         add_source_dialog_filter(dialog, "PDF files", "*.pdf")
+        add_source_dialog_filter(dialog, "Markdown files", "*.md")
         add_source_dialog_filter(dialog, "All files", "*")
         file_name = nil
         if dialog.run == Gtk::Dialog::RESPONSE_ACCEPT
