@@ -261,6 +261,10 @@ module Rabbit
           end
         end
 
+        def convert_hr(element)
+          raise ParseError, _("horizontal rule isn't supported.")
+        end
+
         def convert_comment(element)
           :no_element
         end
@@ -372,6 +376,14 @@ module Rabbit
           # TODO: Should we validate element.options[:category] == "span"?
           Ext::Inline.note(convert_container(element))
         end
+
+        def convert_strikethrough(element)
+          DeletedText.new(text(element.value))
+        end
+
+        def convert_html_element(element)
+          raise ParseError, _("HTML isn't supported.")
+        end
       end
     end
   end
