@@ -40,7 +40,7 @@ module Rabbit
 
     private
     def init_window
-      @window = Gtk::Window.new(Gtk::Window::POPUP)
+      @window = Gtk::Window.new(:popup)
       @window.modal = true
       init_frame
       init_box
@@ -56,7 +56,7 @@ module Rabbit
     end
 
     def init_box
-      @box = Gtk::HBox.new
+      @box = Gtk::Box.new(:horizontal)
       @box.border_width = 3
       @box.show
       @frame.add(@box)
