@@ -51,10 +51,10 @@ theme_exit if @syntax_highlighting_uninstall
     :color => "#4e9a06",
   },
   :integer => {
-    :color => "#c4a000",
+    # :color => "#c4a000",
   },
   :float => {
-    :color => "#c4a000",
+    # :color => "#c4a000",
   },
   :variable => {
     :color => "#ce5c00",
@@ -89,6 +89,18 @@ theme_exit if @syntax_highlighting_uninstall
   :directive => {
     :color => "#5c35cc",
   },
+  :head => {
+    :color => "#204a87",
+  },
+  :change => {
+    :color => "#8f5902",
+  },
+  :delete => {
+    :color => "#a40000",
+  },
+  :insert => {
+    :color => "#4e9a06",
+  },
 }
 
 @syntax_highlighting_foreground ||= "#000000"
