@@ -96,6 +96,40 @@ class RabbitParserMarkdownTest < Test::Unit::TestCase
       end
     end
 
+    class DeletedTextTest < self
+      def test_simple
+        assert_equal([
+                       "Body", [
+                         "Paragraph",
+                         ["Text", "Hello "],
+                         ["DeletedText", ["Text", "deleted"]],
+                         ["Text", " World"],
+                       ],
+                     ],
+                     parse("Hello ~~deleted~~ World"))
+      end
+
+      def test_start_only
+        assert_equal([
+                       "Body", [
+                         "Paragraph",
+                         ["Text", "Hello ~~ World"],
+                       ],
+                     ],
+                     parse("Hello ~~ World"))
+      end
+
+      def test_escaple
+        assert_equal([
+                       "Body", [
+                         "Paragraph",
+                         ["Text", "Hello ~~not deleted~~ World"],
+                       ],
+                     ],
+                     parse("Hello \\~\\~not deleted\\~\\~ World"))
+      end
+    end
+
     class SyntaxHighlightTest < self
       def test_indent_lang
         assert_equal([
@@ -312,5 +346,18 @@ a ![](#{image_path})
         end
       end
     end
+
+    class HorizontalRuleTest < self
+      include Rabbit::GetText
+
+      def test_unsupported
+        message = _("horizontal rule isn't supported.")
+        assert_raise(Rabbit::ParseError.new(message)) do
+          parse(<<-MARKDOWN)
+---
+          MARKDOWN
+        end
+      end
+    end
   end
 end
